@@ -84,8 +84,6 @@ void QMessageFilterContainer::clear()
 BugzillaManager::BugzillaManager(const QString &bugTrackerUrl, QObject *parent)
     : QObject(parent)
     , m_bugTrackerUrl(bugTrackerUrl)
-    , m_logged(false)
-    , m_searchJob(nullptr)
 {
     Q_ASSERT(bugTrackerUrl.endsWith(QLatin1Char('/')));
     Bugzilla::setConnection(new Bugzilla::HTTPConnection(QUrl(m_bugTrackerUrl + QStringLiteral("rest"))));
@@ -98,12 +96,12 @@ void BugzillaManager::lookupVersion()
         try {
             QString version = Bugzilla::version(job);
             setFeaturesForVersion(version);
-            emit bugzillaVersionFound();
+            Q_EMIT bugzillaVersionFound();
         } catch (Bugzilla::Exception &e) {
             // Version detection problems simply mean we'll not mark the version
             // found and the UI will not allow reporting.
             qCWarning(DRKONQI_LOG) << e.whatString();
-            emit bugzillaVersionError(e.whatString());
+            Q_EMIT bugzillaVersionError(e.whatString());
         }
     });
 }
@@ -168,12 +166,12 @@ void BugzillaManager::refreshToken()
             Bugzilla::connection().setToken(m_token);
             m_logged = true;
 
-            emit loginFinished(true);
+            Q_EMIT loginFinished(true);
         } catch (Bugzilla::Exception &e) {
             qCWarning(DRKONQI_LOG) << e.whatString();
             // Version detection problems simply mean we'll not mark the version
             // found and the UI will not allow reporting.
-            emit loginError(e.whatString());
+            Q_EMIT loginError(e.whatString());
         }
     });
 }
@@ -203,10 +201,10 @@ void BugzillaManager::fetchBugReport(int bugnumber, QObject *jobOwner)
             }
             auto bug = list.at(0);
             m_searchJob = nullptr;
-            emit bugReportFetched(bug, jobOwner);
+            Q_EMIT bugReportFetched(bug, jobOwner);
         } catch (Bugzilla::Exception &e) {
             qCWarning(DRKONQI_LOG) << e.whatString();
-            emit bugReportError(e.whatString(), jobOwner);
+            Q_EMIT bugReportError(e.whatString(), jobOwner);
         }
     });
 }
@@ -218,10 +216,10 @@ void BugzillaManager::fetchComments(const Bugzilla::Bug::Ptr &bug, QObject *jobO
     connect(job, &KJob::finished, this, [this, &client, jobOwner](KJob *job) {
         try {
             auto comments = client.getFromBug(job);
-            emit commentsFetched(comments, jobOwner);
+            Q_EMIT commentsFetched(comments, jobOwner);
         } catch (Bugzilla::Exception &e) {
             qCWarning(DRKONQI_LOG) << e.whatString();
-            emit commentsError(e.whatString(), jobOwner);
+            Q_EMIT commentsError(e.whatString(), jobOwner);
         }
     });
 }
@@ -252,10 +250,10 @@ void BugzillaManager::searchBugs(const QStringList &products, const QString &sev
         try {
             auto list = client.search(job);
             m_searchJob = nullptr;
-            emit searchFinished(list);
+            Q_EMIT searchFinished(list);
         } catch (Bugzilla::Exception &e) {
             qCWarning(DRKONQI_LOG) << e.whatString();
-            emit searchError(e.whatString());
+            Q_EMIT searchError(e.whatString());
         }
     });
 }
@@ -267,10 +265,10 @@ void BugzillaManager::sendReport(const Bugzilla::NewBug &bug)
         try {
             int id = Bugzilla::BugClient().create(job);
             Q_ASSERT(id > 0);
-            emit reportSent(id);
+            Q_EMIT reportSent(id);
         } catch (Bugzilla::Exception &e) {
             qCWarning(DRKONQI_LOG) << e.whatString();
-            emit sendReportError(e.whatString());
+            Q_EMIT sendReportError(e.whatString());
         }
     });
 }
@@ -290,10 +288,10 @@ void BugzillaManager::attachTextToReport(const QString &text, const QString &fil
         try {
             QList<int> ids = Bugzilla::AttachmentClient().createAttachment(job);
             Q_ASSERT(ids.size() == 1);
-            emit attachToReportSent(ids.at(0));
+            Q_EMIT attachToReportSent(ids.at(0));
         } catch (Bugzilla::Exception &e) {
             qCWarning(DRKONQI_LOG) << e.whatString();
-            emit attachToReportError(e.whatString());
+            Q_EMIT attachToReportError(e.whatString());
         }
     });
 }
@@ -309,10 +307,10 @@ void BugzillaManager::addMeToCC(int bugId)
         try {
             const auto bugId = Bugzilla::BugClient().update(job);
             Q_ASSERT(bugId != 0);
-            emit addMeToCCFinished(bugId);
+            Q_EMIT addMeToCCFinished(bugId);
         } catch (Bugzilla::Exception &e) {
             qCWarning(DRKONQI_LOG) << e.whatString();
-            emit addMeToCCError(e.whatString());
+            Q_EMIT addMeToCCError(e.whatString());
         }
     });
 }
@@ -329,7 +327,7 @@ void BugzillaManager::fetchProductInfo(const QString &product)
             qCWarning(DRKONQI_LOG) << e.whatString();
             // This doesn't have a string because it is actually not used for
             // anything...
-            emit productInfoError();
+            Q_EMIT productInfoError();
         }
     });
 }
